@@ -22,12 +22,18 @@ is.POSIXlt <- function(x) inherits(x, "POSIXlt")
 #' @export
 is.POSIXct <- function(x) inherits(x, "POSIXct")
 
-#' @export
-c.POSIXct <- function (..., recursive = FALSE) {
-  .POSIXct(c(unlist(lapply(list(...), unclass))), tz = tz(list(...)[[1]]))
+#' @method c POSIXct
+c.POSIXct <- function(..., recursive = FALSE) {
+  dots <- list(...)
+  .POSIXct(c(unlist(lapply(dots, unclass))), tz = tz(dots[[1]]))
 }
 
 #' @method c POSIXlt
-c.POSIXlt <- function (..., recursive = FALSE) {
+c.POSIXlt <- function(..., recursive = FALSE) {
   as.POSIXlt(do.call("c.POSIXct", lapply(list(...), as.POSIXct)))
 }
+
+evalqOnLoad({
+    registerS3method("c", "POSIXct", c.POSIXct)
+    ## registerS3method("c", "POSIXlt", c.POSIXlt)
+})
